@@ -10,9 +10,10 @@
 
 require 'gettext/rmsgfmt'
 require 'iconv'
+include GetText
 
 def parse(data)
-  ret = {}
+  ret = MOFile.new
   parser = PoParser.new
   msgstr = ""
 
